@@ -167,8 +167,11 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
         output = pd.concat([output, pd.DataFrame(client.futures_klines(symbol = symbol, interval = aggreg, startTime = startTime, endTime = endTime, limit = 1000))])
       except json.decoder.JSONDecodeError:
         print('Could not convert to Json. Passing @time:', startTime)
+      #futures_kline
       previousStartTime = startTime
-      startTime = output.loc[:,'time'].max()
+      if output.empty:
+          break
+      startTime = output.loc[:, 0].max()
       if previousStartTime == startTime :
           break
 
@@ -187,8 +190,9 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
 
       except json.decoder.JSONDecodeError:
         print('Could not convert to Json. Passing @time:', startTime)
+      # fincome histo
       previousStartTime = startTime
-      startTime = output.loc[:,'time'].max()
+      startTime = output.loc[:, 'time'].max()
       if previousStartTime == startTime :
           break
   elif (type_ == 'spot_klines')  and (symbol is not None) and (aggreg is not None):
@@ -205,7 +209,7 @@ def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggre
       except json.decoder.JSONDecodeError:
         print('Could not convert to Json. Passing @time:', startTime)
       previousStartTime = startTime
-      startTime = output.loc[:,'time'].max()
+      startTime = output.loc[:, 0].max()
       if previousStartTime == startTime :
           break
 
